@@ -1,3 +1,6 @@
+from collections.abc import KeysView
+
+
 class UUIDdict(dict):
     """
     This objects represents a normal dict, but overwrites the way a new child item is set, asserting its UUID4 id is unique.
@@ -10,6 +13,17 @@ class UUIDdict(dict):
 
         return super().__setitem__(key, child)
 
+    def values_except(self, except_):
+
+        if isinstance(except_, str):
+            result = {k: v for k, v in self.items() if k != except_}
+        elif isinstance(except_, (list, tuple, set, KeysView)):
+            result = {k: v for k, v in self.items() if k not in except_}
+        else:
+            raise TypeError("except_ argument must be a str o sequence instance")
+
+        return result.values()
+
 
 class TranslationDict(dict):
     """
